multi_command_flows

package
v1.11.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: MIT Imports: 36 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var CLIPath = os.TempDir() + string(os.PathSeparator) + "cre" + func() string {
	if os.PathSeparator == '\\' {
		return ".exe"
	}
	return ""
}()

CLI path for testing

Functions

func RunAccountHappyPath

func RunAccountHappyPath(t *testing.T, tc TestConfig, testEthURL, chainName string)

RunAccountHappyPath runs the complete account happy path workflow: Link -> List -> Unlink -> List (verify unlinked)

func RunHappyPath1Workflow

func RunHappyPath1Workflow(t *testing.T, tc TestConfig)

RunHappyPath1Workflow runs the complete happy path 1 workflow: Deploy -> Pause -> Activate -> Delete

func RunHappyPath2Workflow

func RunHappyPath2Workflow(t *testing.T, tc TestConfig)

RunHappyPath2Workflow runs the complete happy path 2 workflow: Deploy -> Deploy update with config

func RunHappyPath3aWorkflow

func RunHappyPath3aWorkflow(t *testing.T, tc TestConfig, projectName, ownerAddress, ethUrl string)

RunHappyPath3aWorkflow runs happy path 3a: Init → Deploy with unlinked key (tests auto-link initiation) This test validates the auto-link flow is triggered but uses --unsigned to avoid contract verification

func RunHappyPath3bWorkflow

func RunHappyPath3bWorkflow(t *testing.T, tc TestConfig)

RunHappyPath3bWorkflow runs happy path 3b: Deploy with linked key + config This test validates successful deployment with config when the key is already linked Note: The workflow directory is created with config-path already set by createWorkflowDirectory

func RunSecretsHappyPath

func RunSecretsHappyPath(t *testing.T, tc TestConfig, chainName string)

RunSecretsHappyPath runs the complete secrets happy path workflow: Create -> Update -> List -> Delete

func RunSecretsListMsig

func RunSecretsListMsig(t *testing.T, tc TestConfig, chainName string)

RunSecretsListMsig on unsigned

func RunSimulationHappyPath

func RunSimulationHappyPath(t *testing.T, tc TestConfig, projectDir string)

Simulates a workflow

func RunWorkflowPrivateRegistryHappyPath added in v1.11.0

func RunWorkflowPrivateRegistryHappyPath(t *testing.T, tc TestConfig)

RunWorkflowPrivateRegistryHappyPath runs the workflow deploy happy path for private registry.

func StripANSI

func StripANSI(s string) string

StripANSI strips the ANSI escape codes from the output

Types

type TestConfig

type TestConfig interface {
	GetCliEnvFlag() string
	GetProjectRootFlag() string
}

TestConfig represents test configuration

Jump to